# kimchima

[![Backend CI/CD 🚀](https://github.com/Aisuko/kimchima/actions/workflows/ci.yml/badge.svg)](https://github.com/Aisuko/kimchima/actions/workflows/ci.yml)
[![Release Drafter 🚀](https://github.com/Aisuko/kimchima/actions/workflows/release-drafter.yml/badge.svg)](https://github.com/Aisuko/kimchima/actions/workflows/release-drafter.yml)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

The collections of tools for ML model development.


# Usage

See examples in the [examples](./examples) directory.


# Development

Please kindly check the .devcontainer directory for the development environment setup.

# Acknowledgement

- [Llama2-burn Project](https://github.com/Gadersd/llama2-burn/tree/main)


# License

This project is licensed as specified in the [LICENSE](./LICENSE) file.